use thiserror;

use crate::pe_parse::error::PEParseError;

#[derive(Debug, thiserror::Error)]
pub enum AppError {
    #[error(transparent)]
    Io(#[from] std::io::Error),

    // 未打开文件映射
    #[error("文件未打开!")]
    NoFileOpened,

    // 文件没有初始化打开
    #[error("文件未初始化打开!")]
    NotInitOpenFile,

    #[error(transparent)]
    PeParseError(#[from] PEParseError),

    /// 初始化打开文件失败
    #[error("初始化打开文件失败!: {0}")]
    InitOpenFileFailed(String),

    /// 无法修改文件
    #[error("无法修改文件!: {0}")]
    CannotModifyFile(String),

    /// 节名过长
    #[error("节名过长!")]
    SectionNameTooLong,
}

impl serde::Serialize for AppError {
    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
    where
        S: serde::ser::Serializer,
    {
        serializer.serialize_str(self.to_string().as_ref())
    }
}
